@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2012 Icinga Developer Team.
+// Copyright (c) 2009-2013 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -30,14 +30,9 @@
  */
 class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviISingletonModel {
 
-    const DEFAULT_CRONK_IMAGE = 'cronks.Folder';
-
-    private static $cat_map = array(
-                                  'catid'       => 'cc_uid',
-                                  'title'       => 'cc_name',
-                                  'visible' => 'cc_visible',
-                                  'position'    => 'cc_position'
-                              );
+    const DEFAULT_CRONK_IMAGE    = 'cronks.Folder';
+    const DEFAULT_CRONK_OWNER    = 'System';
+    const DEFAULT_CRONK_OWNERID  = 0;
 
     private static $cronk_xml_fields = array(
                                            'module', 'action', 'hide', 'description', 'name',
@@ -58,10 +53,12 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
 
     private static $xml_cronk_data = array();
 
-    private static $xml_category_data = array();
-
     private static $xml_ready = false;
 
+    /**
+     * An array full of cronks
+     * @var array
+     */
     private $cronks = array();
 
     /**
@@ -78,22 +75,64 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
      * @var AppKitSecurityUser
      */
     private $agaviUser = null;
+    
+    /**
+     * @var Cronks_Provider_CronksSecurityModel
+     */
+    private $security = null;
+    
+    /**
+     * Category model
+     * @var Cronks_Provider_CronkCategoryDataModel
+     */
+    private $categories = null;
 
     public function initialize(AgaviContext $context, array $parameters = array()) {
         parent::initialize($context, $parameters);
-
+        
         $this->agaviUser = $this->getContext()->getUser();
-
+        
         if ($this->agaviUser->isAuthenticated()===true) {
             $this->user = $this->agaviUser->getNsmUser();
             $this->setPrincipals($this->user->getPrincipalsArray());
         } else {
             throw new AppKitModelException('The model need an authenticated user');
         }
-
+        
         $this->initializeXmlData();
 
-        $this->cronks = $this->getCronks(true);
+        if (!isset($parameters['lazy'])) {
+            $this->cronks = $this->getCronks(true);
+        }
+
+    }
+    
+    /**
+     * Lazy initializing to avoid circular calls
+     * @return Cronks_Provider_CronksDataModel
+     */
+    private function getSecurityModel() {
+        if ($this->security === null) {
+            $this->security = $this->getContext()
+                ->getModel('Provider.CronksSecurity', 'Cronks', array(
+                    'security_only' => true
+                ));
+        }
+        
+        return $this->security;
+    }
+    
+    /**
+     * Lazy categories model
+     * @return Cronks_Provider_CronkCategoryDataModel
+     */
+    private function getCategoryModel() {
+        if ($this->categories === null) {
+            $this->categories = $this->getContext()
+            ->getModel('Provider.CronkCategoryData', 'Cronks');
+        }
+        
+        return $this->categories;
     }
 
     /**
@@ -111,139 +150,40 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
 
         $tmp = include(AgaviConfigCache::checkConfig(AgaviConfig::get('core.config_dir'). '/cronks.xml'));
         self::$xml_cronk_data = (array)$tmp[0] + self::$xml_cronk_data;
-        self::$xml_category_data = (array)$tmp[1] + self::$xml_category_data;
 
         return self::$xml_ready=true;
     }
 
+    /**
+     * Returns true if the cronk exists in the stack
+     * @param string $cronkid
+     * @return boolean
+     */
     public function hasCronk($cronkid) {
         return array_key_exists($cronkid, $this->cronks);
     }
 
+    /**
+     * Rerturn the cronk record
+     * @param string $cronkid
+     * @return mixed cronk struct of type array
+     */
     public function getCronk($cronkid) {
         return $this->cronks[$cronkid];
     }
 
+    /**
+     * Set principals interface to the world
+     * @param array $p
+     */
     public function setPrincipals(array $p) {
         $this->principals = $p;
     }
 
-    private function getXmlCategories() {
-        $out = array();
-        foreach(self::$xml_category_data as $cid=>$category) {
-            $out[ $cid ] = array(
-                               'catid'      => $cid,
-                               'title'      => $category['title'],
-                               'visible'    => isset($category['visible']) ? $category['visible'] : true,
-                               'active' => isset($category['active']) ? $category['active'] : false,
-                               'position'   => isset($category['position']) ? $category['position'] : 0,
-                               'system' => true
-                           );
-        }
-        return $out;
-    }
-
-    private function getDbCategories($get_all=false) {
-        $collection = AppKitDoctrineUtil::createQuery()
-                      ->select('cat.*')
-                      ->from('CronkCategory cat');
-
-        if ($get_all !== true) {
-
-            $p = $this->principals;
-            $p[] = $this->user->user_id;
-
-            $collection->innerJoin('cat.Cronk c')
-            ->innerJoin('c.NsmPrincipal p')
-            ->andWhereIn('p.principal_id', $this->principals);
-        }
-
-        $res = $collection->execute();
-
-        $out = array();
-
-        foreach($res as $category) {
-            $out[$category->cc_uid] = array(
-                                          'catid'       => $category->cc_uid,
-                                          'title'       => $category->cc_name,
-                                          'visible' => (bool)$category->cc_visible,
-                                          'active'  => true,
-                                          'position'    => (int)$category->cc_position,
-                                          'system'  => false
-                                      );
-        }
-
-        return $out;
-    }
-
-    public function getCategories($get_all=false, $show_invisible=false) {
-
-        if ($show_invisible == true && !$this->agaviUser->hasCredential('icinga.cronk.category.admin')) {
-            $show_invisible = false;
-        }
-
-        $cronks = $this->getCronks(true);
-        $categories = $this->getXmlCategories();
-        $categories = (array)$this->getDbCategories($get_all) + $categories;
-
-        AppKitArrayUtil::subSort($categories, 'title');
-        AppKitArrayUtil::subSort($categories, 'position');
-
-        foreach($categories as $cid=>$category) {
-            $count = 0;
-            foreach($cronks as $cronk) {
-                if (isset($cronk['categories']) && $this->matchCategoryString($cronk['categories'], $cid)) {
-                    $count++;
-                }
-            }
-            $categories[$cid]['count_cronks'] = $count;
-
-            if (!$category['visible'] && !$show_invisible) {
-                unset($categories[$cid]);
-            }
-        }
-
-        return $categories;
-    }
-
-    public function deleteCategoryRecord($cc_uid) {
-        if ($this->agaviUser->hasCredential('icinga.cronk.category.admin') && isset($cc_uid)) {
-            $res = AppKitDoctrineUtil::createQuery()
-                   ->delete('CronkCategory cc')
-                   ->andWhere('cc.cc_uid=?', array($cc_uid))
-                   ->limit(1)
-                   ->execute();
-
-            if ($res == 1) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    public function createCategory(array $cat) {
-        AppKitArrayUtil::swapKeys($cat, self::$cat_map, true);
-
-        $category = null;
-
-        if ($this->agaviUser->hasCredential('icinga.cronk.category.admin') && isset($cat['cc_uid'])) {
-            $category = AppKitDoctrineUtil::createQuery()
-                        ->from('CronkCategory cc')
-                        ->andWhere('cc.cc_uid=?', $cat['cc_uid'])
-                        ->execute()->getFirst();
-        }
-
-        if (!$category instanceof CronkCategory || !$category->cc_id > 0) {
-            $category = new CronkCategory();
-        }
-
-        $category->fromArray($cat);
-        $category->save();
-
-        return $category;
-    }
-
+    /**
+     * Check if the user blongs to this groups
+     * @param string$listofnames comma separated list of group names
+     */
     private function checkGroups($listofnames) {
         $groups = AppKitArrayUtil::trimSplit($listofnames, ',');
 
@@ -263,6 +203,10 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return false;
     }
 
+    /**
+     * Check if a user can access this principals
+     * @param string $listofprincipals comma separated string of principals
+     */
     private function checkPrincipals($listofprincipals) {
         $principals = AppKitArrayUtil::trimSplit($listofprincipals);
 
@@ -277,12 +221,42 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return false;
     }
 
+    /**
+     * Return a list of cronks defined in xml
+     * @param boolean $all
+     * @return array
+     */
     private function getXmlCronks($all=false) {
+        // pull cronk xml data from the cache
+        $cached = $this->user->getStorage()->read("icinga.cronks.cache.xml");
+
+        // get me a timestamp for our xml disk cache for cronks
+        $configcache_ts = filemtime(AgaviConfigCache::checkConfig(AgaviConfig::get('core.config_dir'). '/cronks.xml'));
+
+        // do we have any cache?
+        if(isset($cached) and isset($cached["data"])) {
+            // is the cached data newer than that in the xml cache on disk?
+            if(isset($cached["timestamp"]) and $cached["timestamp"] > $configcache_ts) {
+                // return cache
+                return $cached["data"];
+            }
+        }
+
         $out = array();
-
         foreach(self::$xml_cronk_data as $uid=>$cronk) {
-
-            if (isset($cronk['groupsonly']) && $this->checkGroups($cronk['groupsonly']) !== true) {
+            
+            /*
+             * Database credentials overwrite xml credentials
+             */
+            $this->getSecurityModel()->setCronkUid($uid);
+            if ($this->getSecurityModel()->hasDatabaseRoles()) {
+                $cronk['groupsonly'] = $this->getSecurityModel()->getRoleNamesAsString();
+            }
+            
+            if (isset($cronk['groupsonly']) 
+                && $this->checkGroups($cronk['groupsonly']) !== true
+              && $this->agaviUser->hasCredential('icinga.cronk.admin') === false 
+           ) {
                 continue;
             }
 
@@ -292,36 +266,47 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
             elseif(isset($cronk['disabled']) && $cronk['disabled'] == true) {
                 continue;
             }
+            /* ignoring all here - because the cache needs all cronks! -mfrosch
             elseif($all == false && isset($cronk['hide']) && $cronk['hide'] == true) {
                 continue;
             }
+            */
             elseif(!isset($cronk['action']) || !isset($cronk['module'])) {
                 $this->getContext()->getLoggerManager()->log('No action or module for cronk: '. $uid, AgaviLogger::ERROR);
                 continue;
             }
-            
+
             $out[$uid] = array(
-                             'cronkid' => $uid,
-                             'module' => $cronk['module'],
-                             'action' => $cronk['action'],
-                             'hide' => isset($cronk['hide']) ? (bool)$cronk['hide'] : false,
-                             'description' => isset($cronk['description']) ? $cronk['description'] : null,
-                             'name' => isset($cronk['name']) ? $cronk['name'] : null,
-                             'categories' => isset($cronk['categories']) ? $cronk['categories'] : null,
-                             'image' => isset($cronk['image']) ? $cronk['image'] : self::DEFAULT_CRONK_IMAGE,
-                             'disabled' => isset($cronk['disabled']) ? (bool)$cronk['disabled'] : false,
-                             'groupsonly' => isset($cronk['groupsonly']) ? $cronk['groupsonly'] : null,
-                             'state' => isset($cronk['state']) ? $cronk['state'] : null,
-                             'ae:parameter' => isset($cronk['ae:parameter']) ? $cronk['ae:parameter'] : null,
-                             'system' => true,
-                             'owner' => false,
-                             'position' => isset($cronk['position']) ? $cronk['position'] : 0
-                         );
+                'cronkid' => $uid,
+                'module' => $cronk['module'],
+                'action' => $cronk['action'],
+                'hide' => isset($cronk['hide']) ? (bool)$cronk['hide'] : false,
+                'description' => isset($cronk['description']) ? $cronk['description'] : null,
+                'name' => isset($cronk['name']) ? $cronk['name'] : null,
+                'categories' => isset($cronk['categories']) ? $cronk['categories'] : null,
+                'image' => isset($cronk['image']) ? $cronk['image'] : self::DEFAULT_CRONK_IMAGE,
+                'disabled' => isset($cronk['disabled']) ? (bool)$cronk['disabled'] : false,
+                'groupsonly' => isset($cronk['groupsonly']) ? $cronk['groupsonly'] : null,
+                'state' => isset($cronk['state']) ? $cronk['state'] : null,
+                'ae:parameter' => isset($cronk['ae:parameter']) ? $cronk['ae:parameter'] : null,
+                'system' => true,
+                'owner' => false,
+                'position' => isset($cronk['position']) ? $cronk['position'] : 0,
+                'owner_name' => self::DEFAULT_CRONK_OWNER,
+                'owner_id' => self::DEFAULT_CRONK_OWNERID
+            );
+
         }
-        
+        // write data to the cache, with a timestamp
+        $this->user->getStorage()->write("icinga.cronks.cache.xml",array("timestamp" => time(), "data" => $out));
         return $out;
     }
 
+    /**
+     * Creates a cronk array structure based on xml
+     * @param string $xml
+     * @return array
+     */
     private function xml2array($xml) {
         $dom = new DOMDocument('1.0', 'UTF-8');
         $dom->loadXML($xml);
@@ -334,42 +319,68 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return $out;
     }
 
+    /**
+     * Create a cronk array structure based on database cronk recprd
+     * @return array
+     * @param Cronk $cronk
+     */
     private function cronkStructure(Cronk $cronk) {
         $c = $this->xml2array($cronk->cronk_xml);
+        
         $out = array();
         foreach($c as $cuid=>$cd) {
+            
+            $this->getSecurityModel()->setCronkUid($cronk->cronk_uid);
+            
             $out[$cronk->cronk_uid] = array(
-                                          'cronkid' => $cronk->cronk_uid,
-                                          'module' => $cd['module'],
-                                          'action' => $cd['action'],
-                                          'hide' => isset($cd['hide']) ? (bool)$cd['hide'] : false,
-                                          'description' => $cronk->cronk_description ? $cronk->cronk_description : $cd['description'],
-                                          'name' => $cronk->cronk_name ? $cronk->cronk_name : $cd['name'],
-                                          'categories' => isset($cd['categories']) ? $cd['categories'] : null,
-                                          'image' => isset($cd['image']) ? $cd['image'] : self::DEFAULT_CRONK_IMAGE,
-                                          'disabled' => isset($cd['disabled']) ? (bool)$cd['disabled'] : false,
-                                          'groupsonly' => isset($cd['groupsonly']) ? $cd['groupsonly'] : null,
-                                          'state' => isset($cd['state']) ? $cd['state'] : null,
-                                          'ae:parameter' => isset($cd['ae:parameter']) ? $cd['ae:parameter'] : null,
-                                          'system' => false,
-                                          'owner' => ($this->user->user_id == $cronk->cronk_user_id) ? true : false,
-                                          'position' => isset($cd['position']) ? $cd['position'] : 0 
-                                      );
+                'cronkid' => $cronk->cronk_uid,
+                'module' => $cd['module'],
+                'action' => $cd['action'],
+                'hide' => isset($cd['hide']) ? (bool)$cd['hide'] : false,
+                'description' => $cronk->cronk_description ? $cronk->cronk_description : $cd['description'],
+                'name' => $cronk->cronk_name ? $cronk->cronk_name : $cd['name'],
+                'categories' => isset($cd['categories']) ? $cd['categories'] : null,
+                'image' => isset($cd['image']) ? $cd['image'] : self::DEFAULT_CRONK_IMAGE,
+                'disabled' => isset($cd['disabled']) ? (bool)$cd['disabled'] : false,
+                'groupsonly' => $this->getSecurityModel()->getRoleNamesAsString(),
+                'state' => isset($cd['state']) ? $cd['state'] : null,
+                'ae:parameter' => isset($cd['ae:parameter']) ? $cd['ae:parameter'] : null,
+                'system' => false,
+                'owner' => ($this->user->user_id == $cronk->cronk_user_id) ? true : false,
+                'position' => isset($cd['position']) ? $cd['position'] : 0,
+                'owner_name' => $cronk->NsmUser->user_name,
+                'owner_id' => $cronk->NsmUser->user_id
+            );
         }
 
         return $out;
     }
 
-    private function getDbCronks() {
+    /**
+     * Return array of cronks from database
+     * @param boolean $get_all
+     * @return array
+     */
+    private function getDbCronks($get_all = false) {
 
         $p = $this->principals;
 
-        $cronks = AppKitDoctrineUtil::createQuery()
-                  ->from('Cronk c')
-                  ->innerJoin('c.CronkPrincipalCronk cpc')
-                  ->andWhereIn('cpc.cpc_principal_id', $p)
-                  ->execute();
+        $query = AppKitDoctrineUtil::createQuery()
+                  ->from('Cronk c');
 
+        if ($get_all === false
+           && $this->agaviUser->hasCredential('icinga.cronk.admin')===false) {
+            $query->innerJoin('c.CronkPrincipalCronk cpc')
+            ->andWhereIn('cpc.cpc_principal_id', $p);
+        }
+        
+        /*
+         * Don't want system credential entries
+         */
+        $query->andWhere('c.cronk_system=?', false);
+        
+        $cronks = $query->execute();
+        
         $out = array();
 
         foreach($cronks as $cronk) {
@@ -382,14 +393,35 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return $out;
     }
 
+    /**
+     * Get all cronks defined in system
+     * @param boolean $all
+     * @return array
+     */
     public function getCronks($all=false) {
         $cronks = $this->getXmlCronks($all);
         $cronks = (array)$this->getDbCronks() + $cronks;
 
         $this->reorderCronks($cronks);
-
         return $cronks;
     }
+    
+    /**
+     * Return all cronks belongs to a specific category
+     * @param string $category_uid category id
+     * @return array
+     */
+    public function getCronksByCategory($category_uid) {
+        $out = array();
+        $cronks = $this->getCronks(true); // Get all
+        foreach ($cronks as $cid=>$cronk) {
+            if (isset($cronk['categories']) 
+                && AppKitArrayUtil::matchAgainstStringList($cronk['categories'], $category_uid)) {
+                $out[$cid] = $cronk;
+            }
+        }
+        return $out;
+    }
 
     /**
      * @param array $data
@@ -423,7 +455,11 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
                 if (is_array($value)) {
 
                     foreach($value as $sn=>$sv) {
-                        $se = $dom->createElement('ae:parameter', $sv);
+                        // To avoid "unterminated entity reference" warnings /
+                        // exceptions, putt all into cdata section
+                        $cdata = $dom->createCDATASection($sv);
+                        $se = $dom->createElement('ae:parameter');
+                        $se->appendChild($cdata);
                         $se->setAttribute('name', $sn);
                         $ele->appendChild($se);
                     }
@@ -436,19 +472,11 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
                             break;
 
                         case 'groupsonly':
-
-                            $roles = AppKitArrayUtil::trimSplit($value, ',');
-
-                            $arry = AppKitDoctrineUtil::createQuery()
-                                    ->select('r.role_name')
-                                    ->from('NsmRole r INDEXBY r.role_name')
-                                    ->andWhereIn('r.role_id', $roles)
-                                    ->execute(null, Doctrine::HYDRATE_ARRAY);
-
-                            if (isset($arry) && is_array($arry)) {
-                                $value = implode(',', array_keys($arry));
-                            }
-
+                            /*
+                             * Do not save the group attributes within the XML.
+                             * We add them while fetching
+                             */
+                            $value = '';
                             break;
 
                         case 'hide':
@@ -504,15 +532,42 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return $cronk;
     }
 
-    private function cronkBuildRoleDepencies(Cronk $cronk, $roles) {
-
-        $parr = array($this->user->principal->principal_id);
+    /**
+     * Apply users to the cronk, owner
+     * shared principals from groups, ...
+     * 
+     * @param Cronk $cronk
+     * @param string $roles
+     * @return Cronk the modified record
+     */
+    private function cronkBuildPrincipalDependencies(Cronk $cronk, $roles) {
+        
+        $parr = array();
+        
+        /*
+         * Adding existing user principals back to 
+         * cronk ( == owner of the cronk)
+         */
+        foreach ($cronk->CronkPrincipalCronk as $cpc) {
+            if ($cpc->NsmPrincipal->principal_user_id) {
+                $parr[] = $cpc->NsmPrincipal->principal_id;
+            }
+        }
+        
+        /*
+         * If no user principals available, this must be new:
+         * -> defining a new owner of the object
+         */
+        if (count($parr)<=0) {
+            $parr = array($this->user->principal->principal_id);
+        }
 
         $rarr = AppKitArrayUtil::trimSplit($roles, ',');
 
         $cronk->CronkPrincipalCronk->delete();
 
         if (is_array($rarr)) {
+
             $principals = AppKitDoctrineUtil::createQuery()
                           ->select('p.principal_id')
                           ->from('NsmPrincipal p')
@@ -521,7 +576,7 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
                           ->execute();
 
             foreach($principals as $principal) {
-                $parr[] = $principal->principal_id;
+                $parr[] = (integer)$principal->principal_id;
             }
         }
 
@@ -534,7 +589,15 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         foreach($principals as $principal) {
             $cronk->NsmPrincipal[] = $principal;
         }
-
+        
+        /*
+         * If the cronk is new,
+         * no native owner record is set, do this!
+         */
+        if (!$cronk->NsmUser->user_id) {
+            $cronk->NsmUser = $this->user;
+        }
+        
         return $cronk;
     }
 
@@ -547,7 +610,13 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
      * @return Cronk
      */
     public function createCronkRecord(array $data, $load = true) {
-
+        
+        if (
+            $this->agaviUser->hasCredential('icinga.cronk.custom') === false
+           && $this->agaviUser->hasCredential('icinga.cronk.admin') === false) {
+            throw new AppKitModelException('No access to create cronks!');
+        }
+        
         if (!isset($data['cid'])) {
             throw new AppKitModelException('cid is needed for record creation/loading (Cronk UID)');
         }
@@ -565,7 +634,6 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         if (!$record instanceof Cronk) {
             $record = new Cronk();
             $record->cronk_uid = $data['cid'];
-            $record->NsmUser = $this->user;
         }
 
         $record->cronk_description = $data['description'];
@@ -573,19 +641,30 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         $record->cronk_xml = $dom->saveXML($dom);
 
         $this->cronkBuildCategoriesFromString($record, $data['categories']);
-
-        $this->cronkBuildRoleDepencies($record, isset($data['roles']) ? $data['roles'] : null);
-
+        /*
+         * Apply owner, shared users and stuff
+         * like this.
+         */
+        $this->cronkBuildPrincipalDependencies($record, isset($data['roles']) ? $data['roles'] : null);
+        
         return $record;
     }
 
     public function deleteCronkRecord($cronkid, $cronkname, $own=true) {
+        
+        if (
+            $this->agaviUser->hasCredential('icinga.cronk.custom') === false
+           && $this->agaviUser->hasCredential('icinga.cronk.admin') === false) {
+            throw new AppKitModelException('No access to delete cronks!');
+        }
+        
         $q = AppKitDoctrineUtil::createQuery()
              ->select('c.*')
              ->from('Cronk c')
              ->where('c.cronk_uid=?', array($cronkid));
 
-        if ($own==true) {
+        if ($own==true 
+           && $this->agaviUser->hasCredential('icinga.cronk.admin') === false) {
             $q->andWhere('c.cronk_user_id=?', array($this->user->user_id));
         }
 
@@ -618,8 +697,8 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         $cat_out = array();
 
         $cronks_out = array();
-
-        $categories = $this->getCategories();
+        
+        $categories = $this->getCategoryModel()->getCategories();
 
         $cronks = $this->getCronks();
 
@@ -627,25 +706,29 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
             $tmp = array();
 
             foreach($cronks as $cronk) {
-                if ($this->matchCategoryString($cronk['categories'], $category_name)) {
+                // skipping hidden cronks for the output
+                if ($cronk['hide'] == true) {
+                    continue;
+                }
+                if (AppKitArrayUtil::matchAgainstStringList($cronk['categories'], $category_name)) {
                     $tmp[] = $cronk;
                 }
             }
             
             if (($count = count($tmp))) {
                 $cronks_out[$category_name] = array(
-                                                  'rows' => $tmp,
-                                                  'success' => true,
-                                                  'total' => $count
-                                              );
+                    'rows' => $tmp,
+                    'success' => true,
+                    'total' => $count
+                );
                 $cat_out[] = $category;
             }
         }
 
         $data = array(
-                    'categories'    => $cat_out,
-                    'cronks'        => $cronks_out
-                );
+            'categories'    => $cat_out,
+            'cronks'        => $cronks_out
+        );
 
         return $data;
     }
@@ -653,6 +736,7 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
     /**
      * Sorting of cronks based on position flag in the cronk records
      * @param array $cronks
+     * @return array
      */
     private function reorderCronks(array &$cronks) {
         
@@ -670,9 +754,4 @@ class Cronks_Provider_CronksDataModel extends CronksBaseModel implements AgaviIS
         return $cronks;
     }
 
-    private function matchCategoryString($categories, $match) {
-        $match=preg_quote($match);
-        return preg_match('/(^|,)'. $match. '(,|$)/i', $categories);
-    }
-
 }
