@@ -25,6 +25,8 @@
 class IcingaDataPrincipalTarget extends AppKitPrincipalTarget {
     protected $defaultTarget = '';
     protected $api_mapping_fields = array();
+    protected $ornull = false;
+    protected $ornullfield = null;
 
     public function getApiMappingFields() {
         return $this->api_mapping_fields;
@@ -57,6 +59,14 @@ class IcingaDataPrincipalTarget extends AppKitPrincipalTarget {
                 $p[] = sprintf('${%s} LIKE \'%s\'', $this->getApiMappingField($k), $v);
             }
         }
+        if ($this->ornull == true) {
+            if (isset($this->ornullfield)) {
+                $p[] = sprintf('%s IS NULL', $this->ornullfield);
+            }
+            else {
+                $p[] = sprintf('${%s} IS NULL', $this->getApiMappingField($k));
+            }
+        }
 
         return '('. join(' OR ', $p). ')';
     }
